english_word_dict = {
    # Main
    "application_name": "AutoControlGUI",
    # Widget
    "param": "Param",
    "url": "URL: ",
    "send": "Send: ",
    "response_and_log": "Response / Log:",
    # Widget Log
    "status_code": "Status Code: ",
    "text": "Text: ",
    "headers": "Headers: ",
    "content": "Content: ",
    "history": "History: ",
    "encoding": "Encoding: ",
    "cookies": "Cookies: ",
    "elapsed": "Elapsed: ",
    "request_method": "Request Method: ",
    "request_url": "Request URL: ",
    "request_body": "Request Body: ",
    # Test method
    "get": "GET",
    "post": "POST",
    "put": "PUT",
    "patch": "PATCH",
    "delete": "DELETE",
    "head": "HEAD",
    "options": "OPTIONS",
}
